module Config.Helpers.CardFormat exposing (..)

import Config.Data.Identity
    exposing
        ( pageNames
        )
import Config.Helpers.Converters exposing (formatName)
import Config.Helpers.Format
    exposing
        ( headerFontSizeMedium
        , paragraphFontSize
        , paragraphSpacing
        )
import Config.Style.Colour exposing (colourTheme)
import Config.Style.Glow
    exposing
        ( glowDeepDarkGrey
        , glowDeepDarkOrange
        )
import Config.Style.Icons.Icons exposing (construction)
import Config.Style.Transitions
    exposing
        ( hoverCircleButtonDarkOrange
        , transitionStyleMedium
        , transitionStyleSlow
        )
import Element as E exposing (..)
import Element.Background as B
import Element.Border as D
import Element.Font as F
import Html.Attributes as H
import Route.Path as Path exposing (..)
import Shared


cardMaker : Device -> String -> List (Element msg) -> { description : String, src : String } -> String -> Element msg
cardMaker device title content image url =
    el
        [ width (fill |> minimum 100)
        , width (fill |> maximum 875)
        , padding 10
        , centerX
        ]
    <|
        if
            url
                == Path.toString Path.Home_
                || url
                == Path.toString Path.Contact
                || url
                == Path.toString Path.Debate
                || url
                == Path.toString Path.Debate_Arguments
                || url
                == Path.toString Path.Debate_Cucklist
                || url
                == Path.toString Path.Debate_Gibberish
                || url
                == Path.toString Path.Donate
                || url
                == Path.toString Path.Blog
                || url
                == Path.toString Path.Blog_Seedoils
                || url
                == Path.toString Path.Blog_Huntergatherers
                || url
                == Path.toString Path.Blog_Sapiendiet
                || url
                == Path.toString Path.Blog_Nagragoodrich
                || url
                == Path.toString Path.Blog_Quacksmashing
                || url
                == Path.toString Path.Blog_Bigfatsurprise
                || url
                == Path.toString Path.Blog_Everettvegans
                || url
                == Path.toString Path.Blog_Meatapologetics
                || url
                == Path.toString Path.Blog_Plantbasedmeta
                || url
                == Path.toString Path.Blog_Shenanigans
                || url
                == Path.toString Path.Blog_Sweetdeception
                || url
                == Path.toString Path.Interviews
                || url
                == Path.toString Path.Nutridex
                || url
                == Path.toString Path.Services
                || url
                == Path.toString Path.Services_Analysis
                || url
                == Path.toString Path.Services_Coaching
                || url
                == Path.toString Path.Services_Elm
                || url
                == Path.toString Path.Services_Nix
                || url
                == Path.toString Path.Services_Nutrition
        then
            el
                [ E.width fill
                , D.width 5
                , D.color colourTheme.backgroundDarkGrey
                , D.rounded 32
                , glowDeepDarkGrey
                , mouseOver
                    [ D.color colourTheme.textDarkOrange
                    , B.color colourTheme.textDarkOrange
                    , glowDeepDarkOrange
                    ]
                , transitionStyleSlow
                ]
            <|
                link [ width fill ]
                    { url = url
                    , label = cardStructure device title content image
                    }

        else
            el
                [ E.width fill
                , D.width 5
                , D.color colourTheme.backgroundDarkGrey
                , D.rounded 32
                , glowDeepDarkGrey
                , mouseOver
                    [ D.color colourTheme.textDarkOrange
                    , B.color colourTheme.textDarkOrange
                    , glowDeepDarkOrange
                    ]
                , transitionStyleSlow
                ]
            <|
                newTabLink []
                    { url = url
                    , label = cardStructure device title content image
                    }


cardStructure : Device -> String -> List (Element msg) -> { description : String, src : String } -> Element msg
cardStructure device title content image =
    column
        [ width fill
        ]
        [ el
            [ headerFontSizeMedium
            , F.bold
            , F.color colourTheme.textLightGrey
            , B.color colourTheme.textDarkOrange
            , paddingEach
                { top = 6
                , bottom = 3
                , left = 20
                , right = 20
                }
            , width fill
            , F.center
            , D.roundEach
                { topLeft = 26
                , topRight = 26
                , bottomRight = 0
                , bottomLeft = 0
                }
            ]
          <|
            paragraph [] [ text title ]
        , el
            [ E.height fill
            , E.width fill
            , centerX
            , B.color colourTheme.backgroundDarkGrey
            , padding 10
            , D.roundEach
                { topLeft = 0
                , topRight = 0
                , bottomRight = 26
                , bottomLeft = 26
                }
            , spacing 8
            ]
          <|
            el
                [ paddingEach
                    { top = 0
                    , bottom = 0
                    , left = 15
                    , right = 15
                    }
                , spacing 8
                , width fill
                ]
            <|
                row
                    [ width fill ]
                    [ column
                        [ spacing 8
                        , width fill
                        ]
                        content
                    , el
                        [ alignRight
                        , alignTop
                        , paddingXY 20 20
                        ]
                      <|
                        el
                            [ D.rounded 100
                            , D.width 5
                            , glowDeepDarkGrey
                            , D.color colourTheme.backgroundDarkGrey
                            , B.color colourTheme.backgroundDarkGrey
                            ]
                        <|
                            E.image
                                ([ alignRight
                                 , alignTop
                                 , D.rounded 100
                                 , clip
                                 ]
                                    ++ (case ( device.class, device.orientation ) of
                                            ( Phone, Portrait ) ->
                                                [ E.width <| px 45
                                                , E.height <| px 45
                                                ]

                                            ( Tablet, Portrait ) ->
                                                [ E.width <| px 45
                                                , E.height <| px 45
                                                ]

                                            _ ->
                                                [ E.width <| px 90
                                                , E.height <| px 90
                                                ]
                                       )
                                )
                                image
                    ]
        ]
